@@ -10,16 +10,32 @@ import shutil
 from pathlib import Path
 
 
-file_folder = os.path.dirname(__file__)
+file_folder = Path(__file__).parent
+top_folder = (file_folder / ".." / "peek").resolve()
+sys.path.insert(0, str(top_folder))
 os.chdir(file_folder)
-sys.path.insert(0, file_folder + "/../peek")
 
 import peek
 
 peek = peek.new(ignore_toml=True)
 
-globals().update(peek.ANSI.__dict__)  # put white, red, ..., dark_yellow in globals
-
+dark_black=peek.ANSI.dark_black
+dark_red=peek.ANSI.dark_red
+dark_green=peek.ANSI.dark_green
+dark_yellow=peek.ANSI.dark_yellow
+dark_blue=peek.ANSI.dark_blue
+dark_magenta=peek.ANSI.dark_magenta
+dark_cyan=peek.ANSI.dark_cyan
+dark_white=peek.ANSI.dark_white
+black=peek.ANSI.black
+red=peek.ANSI.red
+green=peek.ANSI.green
+yellow=peek.ANSI.yellow
+blue=peek.ANSI.blue
+magenta=peek.ANSI.magenta
+cyan=peek.ANSI.cyan
+white=peek.ANSI.white
+reset=peek.ANSI.reset
 
 class g:
     pass
@@ -304,6 +320,15 @@ def test_as_str():
         assert s == "hello='world'\n"
 
 
+def test_colored_end(capsys):
+    hello = "world"
+    s = peek(hello, color="red", end="|", as_str=True)
+    assert s == f"{red}hello='world'{reset}{red}|{reset}"
+    peek(hello, color="red", end="|")
+    out, err = capsys.readouterr()
+    assert out == f"{red}hello='world'{reset}{red}|{reset}"
+
+
 @pytest.mark.skipif(Pythonista, reason="Pythonista problem")
 def test_print(capsys):
     peek.print(*range(4))
@@ -1198,6 +1223,7 @@ def test_stop():
     peek.stop
     peek.enabled = True
 
+
 @pytest.mark.skipif(Pythonista, reason="Pythonista problem")
 def test_max_lines(capsys):
     a = [list(range(i, i + 10)) for i in range(10, 100, 10)]
@@ -1246,4 +1272,3 @@ def test_line_length():
 
 if __name__ == "__main__":
     pytest.main(["-vv", "-s", "-x", __file__])
-
